@@ -1,4 +1,4 @@
-# $Id: RelationshipType.pm 1845 2010-01-08 12:33:09Z erant $
+# $Id: RelationshipType.pm 1845 2010-08-21 12:33:09Z easr $
 #
 # Module  : RelationshipType.pm
 # Purpose : Type of Relationship in the Ontology: is_a, part_of, etc.
@@ -43,6 +43,13 @@ $r2->name("part of");
 $r3->name("participates in");
 
 
+# rel. type creator + date
+
+$r1->created_by("erick_antezana");
+
+$r1->creation_date("2008-04-13T01:32:36Z ");
+
+
 # inverse
 
 my $r3_inv = OBO::Core::RelationshipType->new();
@@ -99,30 +106,32 @@ sub new {
         my $class                   = shift;
         my $self                    = {};
         
-        $self->{ID}                 = undef; # required, string (1)
-        $self->{NAME}               = undef; # required, string (1)
+        $self->{ID}                 = undef;                 # required, string (1)
+        $self->{NAME}               = undef;                 # required, string (1)
         
         $self->{ALT_ID}             = OBO::Util::Set->new(); # set (0..N)
-        $self->{DEF}                = OBO::Core::Def->new; # (0..1)
+        $self->{DEF}                = OBO::Core::Def->new;   # (0..1)
         $self->{NAMESPACE_SET}      = OBO::Util::Set->new(); # set (0..N)
-        $self->{COMMENT}            = undef; # string (0..1)
+        $self->{COMMENT}            = undef;                 # string (0..1)
         $self->{SUBSET_SET}         = OBO::Util::Set->new(); # set of scalars (0..N)
         $self->{SYNONYM_SET}        = OBO::Util::SynonymSet->new(); # set of synonyms (0..N)
-        $self->{XREF_SET}           = OBO::Util::DbxrefSet->new(); # set of dbxref's (0..N)
+        $self->{XREF_SET}           = OBO::Util::DbxrefSet->new();  # set of dbxref's (0..N)
         $self->{DOMAIN}             = OBO::Util::Set->new(); # set of scalars (0..N)
         $self->{RANGE}              = OBO::Util::Set->new(); # set of scalars (0..N)
-        $self->{IS_CYCLIC}          = undef; # [1|0], 0 by default
-        $self->{IS_REFLEXIVE}       = undef; # [1|0], 0 by default
-        $self->{IS_SYMMETRIC}       = undef; # [1|0], 0 by default
-        $self->{IS_ANTI_SYMMETRIC}  = undef; # [1|0], 0 by default
-        $self->{IS_TRANSITIVE}      = undef; # [1|0], 0 by default
-        $self->{IS_METADATA_TAG}    = undef; # [1|0], 0 by default
-        $self->{INVERSE_OF}         = undef; # string (0..1)
+        $self->{IS_CYCLIC}          = undef;                 # [1|0], 0 by default
+        $self->{IS_REFLEXIVE}       = undef;                 # [1|0], 0 by default
+        $self->{IS_SYMMETRIC}       = undef;                 # [1|0], 0 by default
+        $self->{IS_ANTI_SYMMETRIC}  = undef;                 # [1|0], 0 by default
+        $self->{IS_TRANSITIVE}      = undef;                 # [1|0], 0 by default
+        $self->{IS_METADATA_TAG}    = undef;                 # [1|0], 0 by default
+        $self->{INVERSE_OF}         = undef;                 # string (0..1)
         $self->{TRANSITIVE_OVER}    = OBO::Util::Set->new(); # set of scalars (0..N)
-        $self->{IS_OBSOLETE}        = undef; # [1|0], 0 by default
+       	$self->{CREATED_BY}         = undef;                 # scalar (0..1)
+		$self->{CREATION_DATE}      = undef;                 # scalar (0..1)
+        $self->{IS_OBSOLETE}        = undef;                 # [1|0], 0 by default
         $self->{REPLACED_BY}        = OBO::Util::Set->new(); # set of scalars (0..N)
 		$self->{CONSIDER}           = OBO::Util::Set->new(); # set of scalars (0..N)
-        $self->{BUILTIN}            = undef; # [1|0], 0 by default
+        $self->{BUILTIN}            = undef;                 # [1|0], 0 by default
 	
         bless ($self, $class);
         return $self;
@@ -614,6 +623,34 @@ sub transitive_over {
 	return $self->{TRANSITIVE_OVER};
 }
 
+=head2 created_by
+
+  Usage    - print $relationship_type->created_by() or $relationship_type->created_by("erick_antezana")
+  Returns  - name (string) of the creator of the relationship type, may be a short username, initials or ID
+  Args     - name (string) of the creator of the relationship type, may be a short username, initials or ID
+  Function - gets/sets the name of the creator of the relationship type
+  
+=cut
+sub created_by {
+	my ($self, $created_by) = @_;
+	if ($created_by) { $self->{CREATED_BY} = $created_by }
+	return $self->{CREATED_BY};
+}
+
+=head2 creation_date
+
+  Usage    - print $relationship_type->creation_date() or $relationship_type->creation_date("2010-04-13T01:32:36Z")
+  Returns  - date (string) of creation of the relationship type specified in ISO 8601 format
+  Args     - date (string) of creation of the relationship type specified in ISO 8601 format
+  Function - gets/sets the date of creation of the relationship type
+  
+=cut
+sub creation_date {
+	my ($self, $creation_date) = @_;
+	if ($creation_date) { $self->{CREATION_DATE} = $creation_date }
+	return $self->{CREATION_DATE};
+}
+
 =head2 is_obsolete
 
   Usage    - print $relationship_type->is_obsolete()
